"use strict";
exports.__esModule = true;
exports.DOM = void 0;
/**
 * Manipulates the DOM
 */
exports.DOM = {
    cache: {
        id: 0
    },
    /**
     * Creates a new DOM element
     */
    "new": function (type, options) {
        if (options === void 0) { options = {}; }
        var element = document.createElement(type), attributes = Object.keys(options);
        element.domId = exports.DOM.cache.id;
        attributes.forEach(function (attribute) {
            if (attribute.toLowerCase() === 'text') {
                element.textContent = options[attribute];
            }
            else {
                element.setAttribute(attribute, options[attribute]);
            }
        });
        exports.DOM.cache.id++;
        return element;
    },
    /**
     * Wraps a DOM element
     */
    wrap: function (element, type, options) {
        var container = exports.DOM["new"](type, options);
        container.appendChild(element);
        return container;
    },
    /**
     * Element styling
     */
    style: {
        /**
         * Set CSS using objects
         */
        set: function (element, styling) {
            if (element) {
                var keys = Object.keys(styling);
                (keys).forEach(function (key) {
                    element.style[key] = styling[key];
                });
            }
        }
    },
    attributes: {
        set: function (element, attributes) {
            if (element) {
                var keys = Object.keys(attributes);
                (keys).forEach(function (key) {
                    element.setAttribute(key, attributes[key]);
                });
            }
        }
    },
    getIndex: function (element) {
        return Array.from(element.parentNode.children).indexOf(element);
    }
};
//# sourceMappingURL=dom.js.map