"use strict";
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
exports.__esModule = true;
exports.objHas = exports.applyNested = exports.getNested = exports.getNestedPath = exports.setNestedPath = exports.checkNested = exports.checkNestedPath = void 0;
/**
 * Checks an object for the existance nested path
 */
var checkNestedPath = function (obj, path) {
    path = Array.isArray(path) ? path : path.split('.');
    for (var i = 0; i < path.length; i++) {
        if (!obj || !Object.prototype.hasOwnProperty.call(obj, path[i])) {
            return false;
        }
        obj = obj[path[i]];
    }
    return true;
};
exports.checkNestedPath = checkNestedPath;
/**
 * Checks an object for a nested value
 */
var checkNested = function (obj) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    for (var i = 0; i < args.length; i++) {
        if (!obj || !Object.prototype.hasOwnProperty.call(obj, args[i])) {
            return false;
        }
        obj = obj[args[i]];
    }
    return true;
};
exports.checkNested = checkNested;
/**
 * Sets an object value using a path
 */
var setNestedPath = function (obj, path, value) {
    path = Array.isArray(path) ? path : path.split('.');
    var wasSet = false;
    for (var i = 0; i < path.length; i++) {
        if (!obj || !Object.prototype.hasOwnProperty.call(obj, path[i])) {
            continue;
        }
        if (i === (path.length - 1)) {
            obj[path[i]] = value;
            wasSet = true;
        }
        obj = obj[path[i]];
    }
    return wasSet;
};
exports.setNestedPath = setNestedPath;
/**
 * Retrieves an object value using path
 */
var getNestedPath = function (obj, path, fallback) {
    path = Array.isArray(path) ? path : path.split('.');
    for (var i = 0; i < path.length; i++) {
        if (!obj || !Object.prototype.hasOwnProperty.call(obj, path[i])) {
            return fallback;
        }
        obj = obj[path[i]];
    }
    return obj;
};
exports.getNestedPath = getNestedPath;
/**
 * Retrieves an object value using path
 */
var getNested = function (obj, fallback) {
    var args = [];
    for (var _i = 2; _i < arguments.length; _i++) {
        args[_i - 2] = arguments[_i];
    }
    for (var i = 0; i < args.length; i++) {
        if (!obj || !Object.prototype.hasOwnProperty.call(obj, args[i])) {
            return fallback;
        }
        obj = obj[args[i]];
    }
    return obj;
};
exports.getNested = getNested;
/**
 * Applies a nested value to an object key
 */
var applyNested = function (dest, key, origin, fallback) {
    var nested = [];
    for (var _i = 4; _i < arguments.length; _i++) {
        nested[_i - 4] = arguments[_i];
    }
    if (dest) {
        var exists = exports.checkNested.apply(void 0, __spreadArray([origin], nested, false));
        dest[key] = exists ? exports.getNested.apply(void 0, __spreadArray([origin, fallback], nested, false)) : fallback;
        return dest[key];
    }
    return null;
};
exports.applyNested = applyNested;
/**
 * Tests the existance of a path within an object
 */
var objHas = function (obj, path) {
    var level = null;
    var rest = [];
    if (!path.includes('.')) {
        level = path;
    }
    else {
        rest = path.split('.');
        level = rest.shift();
    }
    if (obj === undefined) {
        return false;
    }
    if (rest.length === 0 &&
        Object.prototype.hasOwnProperty.call(obj, level)) {
        return true;
    }
    return (0, exports.objHas)(obj[level], rest.join('.'));
};
exports.objHas = objHas;
//# sourceMappingURL=objUtils.js.map