"use strict";
exports.__esModule = true;
exports.setVideoVolume = exports.showVolumeIndicator = void 0;
var dom_1 = require("./dom");
var timerVolumeIndicator = null;
/**
 * Shows the volume indicator when scrolling on a video preview
 */
var showVolumeIndicator = function (volume) {
    clearTimeout(timerVolumeIndicator);
    var container = document.body.querySelector(':scope > div#indicatorPreviewVolume');
    /* Create text */
    var volumeText = (volume === 0 ? 'Muted' : "Volume: ".concat(volume, "%"));
    if (!container) {
        /* Create element if non-existant */
        container = dom_1.DOM["new"]('div', {
            id: 'indicatorPreviewVolume',
            text: volumeText
        });
        document.body.prepend(container);
    }
    else {
        container.textContent = volumeText;
    }
    /* Show element */
    setTimeout(function () {
        dom_1.DOM.style.set(container, {
            opacity: '1'
        });
    });
    /* Hide element */
    timerVolumeIndicator = window.setTimeout(function () {
        dom_1.DOM.style.set(container, {
            opacity: '0'
        });
    }, 2500);
};
exports.showVolumeIndicator = showVolumeIndicator;
/**
 * Sets the volume of a video preview
 */
var setVideoVolume = function (video, volume, indicator) {
    if (indicator === void 0) { indicator = true; }
    if (!video)
        return;
    var muted = !(volume > 0);
    video.muted = muted;
    video.volume = muted ? 0 : volume <= 100 ? volume : 100;
    /* Catch errors (uninteracted with DOM) and mute on error */
    video.play().then(function () {
        if (indicator) {
            (0, exports.showVolumeIndicator)(Math.round(video.volume * 100));
        }
    })["catch"](function () {
        video.muted = true;
        video.volume = 0;
        if (indicator) {
            (0, exports.showVolumeIndicator)(Math.round(video.volume * 100));
        }
        video.play();
    });
};
exports.setVideoVolume = setVideoVolume;
//# sourceMappingURL=previewUtils.js.map