"use strict";
exports.__esModule = true;
exports.addLeading = exports.addTrailing = exports.stripExtension = exports.trimBoth = exports.trimRight = exports.trimLeft = exports.stripUrl = exports.identifyExtension = exports.shortenString = exports.capitalize = void 0;
/**
 * Capitalizes an input
 */
var capitalize = function (input) {
    return input.charAt(0).toUpperCase() + input.slice(1);
};
exports.capitalize = capitalize;
/**
 * Shortens a string
 */
var shortenString = function (input, cutoff) {
    cutoff = cutoff || 28;
    if (input.length > cutoff) {
        return [
            input.substring(0, Math.floor((cutoff / 2) - 2)),
            input.substring(input.length - (Math.floor((cutoff / 2) - 2)), input.length)
        ].join(' .. ');
    }
    else {
        return input;
    }
};
exports.shortenString = shortenString;
/**
* Identifies extension
*/
var identifyExtension = function (url, extensions) {
    if (extensions === void 0) { extensions = {
        image: [],
        video: []
    }; }
    var extension = (url).split('.').pop().toLowerCase();
    if (extensions.image.includes(extension)) {
        return [extension, 0];
    }
    else if (extensions.video.includes(extension)) {
        return [extension, 1];
    }
    return null;
};
exports.identifyExtension = identifyExtension;
/**
 * Strips `?` and anything that follows from a URL
 */
var stripUrl = function (url) {
    return !url.includes('?') ? url : url.split('?')[0];
};
exports.stripUrl = stripUrl;
/**
 * Trimming functions
 */
var trimLeft = function (s, char) {
    return s.startsWith(char) ? s.substr(1) : s;
};
exports.trimLeft = trimLeft;
var trimRight = function (s, char) {
    return s.endsWith(char) ? s.slice(0, -1) : s;
};
exports.trimRight = trimRight;
var trimBoth = function (s, char) {
    return (0, exports.trimRight)((0, exports.trimLeft)(s, char), char);
};
exports.trimBoth = trimBoth;
/**
 * Strips the extension from a string
 */
var stripExtension = function (string) {
    return string.replace(/\.[^/.]+$/, '');
};
exports.stripExtension = stripExtension;
/**
 * Adds a trailing character to a string IF it does not already exist
 */
var addTrailing = function (s, char) {
    return s.endsWith(char) ? s : (s + char);
};
exports.addTrailing = addTrailing;
/**
 * Adds a leading character to a string IF it does not already exist
 */
var addLeading = function (s, char) {
    return s.startsWith(char) ? s : (char + s);
};
exports.addLeading = addLeading;
//# sourceMappingURL=stringUtils.js.map